000010 IDENTIFICATION DIVISION.
000020*@S              Static or dynamic subroutine
000030 PROGRAM-ID. SMAIL2.
000040 DATE-COMPILED.
000050* ------------------------: Simple mail demo program
000060*                         : Used to demonstrate GUI-ScreenIO's
000070*                         : mail   API calls.
000080*                         :
000090*                         : Designed to be compiled as a static
000100*                         : or dynamic subroutine called with one
000110*                         : argument for automated sending of
000120*                         : machine generated mail.
000130*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
000140 ENVIRONMENT DIVISION.
000150*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
000160 CONFIGURATION SECTION.
000170 SOURCE-COMPUTER. IBM-PC.
000180 OBJECT-COMPUTER. IBM-PC.
000190*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
000200 DATA DIVISION.
000210*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
000220 WORKING-STORAGE SECTION.
000230 01  V--VERSION-LEVEL                 PIC 9(3) VALUE 4.
000240* -====-
000250         COPY WIN32API.
000260         COPY REGISTRY.
000270         COPY MAILAPI.
000280*
000290*                         : Used to split up email addresses
000300 01  WS-USER-EMAIL-NAME               PIC X(100).
000310 01  WS-USER-EMAIL-DOMAIN             PIC X(100).
000320 01  WS-USER-EMAIL-AT-SIGN            PIC X.
000330* -====-
000340 01  WS-SMAIL-WORKING-FIELDS.
000350     05  SM-YOUR-EMAIL                PIC X(0100) VALUE SPACE.
000360     05  SM-SMTP-SERVER               PIC X(0150) VALUE SPACE.
000370     05  SM-PORT                      PIC 9(4) VALUE 25.
000380     05  SM-YOUR-NAME                 PIC X(50) VALUE SPACE.
000390     05  SM-USE-AUTH                  PIC 9 VALUE 0.
000400       88  SM-USE-AUTH-ON             VALUE 1.
000410       88  SM-USE-AUTH-OFF            VALUE 0.
000420     05  SM-YOUR-LOGIN-NAME           PIC X(50) VALUE SPACE.
000430     05  SM-YOUR-PASSWORD             PIC X(50) VALUE SPACE.
000440*
000450*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
000460 LINKAGE SECTION.
000470* -====-
000480 01  LN-EMAIL-ARGUMENT-AREA.
000490*                         : Input Fields:
000500     05  LN-TO-NAME                   PIC X(250).
000510     05  LN-TO-EMAIL                  PIC X(250).
000520     05  LN-SUBJECT                   PIC X(200).
000530     05  LN-TEXT                      PIC X(20000).
000540*                         : These are output fields
000550     05  LN-ERROR-TEXT                PIC X(200).
000560     05  LN-SUCCESS-FAIL              PIC X.
000570*                         : Bad status
000580       88  LN-MESSAGE-FAILED          VALUE 'F'.
000590*                         : Good status
000600       88  LN-MESSAGE-SENT-OK         VALUE 'S'.
000610*
000620*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
000630 PROCEDURE DIVISION USING LN-EMAIL-ARGUMENT-AREA.
000640*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
000650*
000660*                         : Feel free to flesh this section out
000670*                         : with better error checking.
000680*                         : First we fetch our settings
000690     PERFORM 0102-FETCH-SETTINGS.
000700*                         : Then we send the mail.
000710     PERFORM 0103-SEND-MAIL.
000720*
000730     GOBACK.
000740*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
000750 0100-GS-UTILITY SECTION.
000760* -====-
000770 0101-API-CALL.
000780     MOVE 'MailSettings' TO REGISTRY-SUBKEY.
000790     CALL 'GSWINAPI' USING WIN32API-PARMS
000800                           REGISTRY-PARMS
000810                           WIN32API-B
000820                           WIN32API-C
000830                           WIN32API-D
000840                           WIN32API-E
000850                           WIN32API-F.
000860*
000870* -====-
000880 0102-FETCH-SETTINGS.
000890     MOVE LOW-VALUES TO
000900         SM-YOUR-EMAIL
000910         SM-SMTP-SERVER
000920         WS-USER-EMAIL-NAME
000930         WS-USER-EMAIL-DOMAIN
000940         WS-USER-EMAIL-AT-SIGN
000950     MOVE 25 TO SM-PORT.
000960*
000970*                         : Upon being initiated, we fetch our
000980*                         : settings from the registry and load
000990*                         : our working storage fields.
001000*                         : First - email address
001010     SET REGISTRY-DATA-IS-TEXT TO TRUE.
001020     MOVE 'Email Address' TO REGISTRY-VALUENAME.
001030     MOVE LOW-VALUES TO REGISTRY-DATA.
001040     SET FUNC-REGISTRY-GET TO TRUE.
001050     PERFORM 0101-API-CALL.
001060     IF NOT WIN32API-FAILED
001070       IF REGISTRY-DATA-LENGTH > ZERO
001080         MOVE REGISTRY-DATA (1:REGISTRY-DATA-LENGTH)
001090             TO SM-YOUR-EMAIL.
001100*
001110*                         : Second Smtp server address
001120     SET REGISTRY-DATA-IS-TEXT TO TRUE.
001130     MOVE 'SMTP Server' TO REGISTRY-VALUENAME.
001140     MOVE LOW-VALUES TO REGISTRY-DATA.
001150     SET FUNC-REGISTRY-GET TO TRUE.
001160     PERFORM 0101-API-CALL.
001170     IF NOT WIN32API-FAILED
001180       IF REGISTRY-DATA-LENGTH > ZERO
001190         MOVE REGISTRY-DATA (1:REGISTRY-DATA-LENGTH)
001200             TO SM-SMTP-SERVER.
001210*
001220*                         : Fetch the smtp port
001230     SET REGISTRY-DATA-IS-TEXT TO TRUE.
001240     MOVE 'SMTP Port' TO REGISTRY-VALUENAME.
001250     MOVE LOW-VALUES TO REGISTRY-DATA.
001260     SET FUNC-REGISTRY-GET TO TRUE.
001270     PERFORM 0101-API-CALL.
001280     IF NOT WIN32API-FAILED
001290       IF REGISTRY-DATA-LENGTH > ZERO
001300         MOVE REGISTRY-DATA (1:REGISTRY-DATA-LENGTH)
001310             TO SM-PORT.
001320*
001330     SET REGISTRY-DATA-IS-TEXT TO TRUE.
001340     MOVE 'User Name' TO REGISTRY-VALUENAME.
001350     MOVE LOW-VALUES TO REGISTRY-DATA.
001360     SET FUNC-REGISTRY-GET TO TRUE.
001370     PERFORM 0101-API-CALL.
001380     IF NOT WIN32API-FAILED
001390       IF REGISTRY-DATA-LENGTH > ZERO
001400         MOVE REGISTRY-DATA (1:REGISTRY-DATA-LENGTH)
001410             TO SM-YOUR-NAME.
001420*
001430     SET REGISTRY-DATA-IS-TEXT TO TRUE.
001440     MOVE 'User LOGIN' TO REGISTRY-VALUENAME.
001450     MOVE LOW-VALUES TO REGISTRY-DATA.
001460     SET FUNC-REGISTRY-GET TO TRUE.
001470     PERFORM 0101-API-CALL.
001480     IF NOT WIN32API-FAILED
001490       IF REGISTRY-DATA-LENGTH > ZERO
001500         MOVE REGISTRY-DATA (1:REGISTRY-DATA-LENGTH)
001510             TO SM-YOUR-LOGIN-NAME.
001520*
001530     SET REGISTRY-DATA-IS-TEXT TO TRUE.
001540     MOVE 'User PASSWD' TO REGISTRY-VALUENAME.
001550     MOVE LOW-VALUES TO REGISTRY-DATA.
001560     SET FUNC-REGISTRY-GET TO TRUE.
001570     PERFORM 0101-API-CALL.
001580     IF NOT WIN32API-FAILED
001590       IF REGISTRY-DATA-LENGTH > ZERO
001600         MOVE REGISTRY-DATA (1:REGISTRY-DATA-LENGTH)
001610             TO SM-YOUR-PASSWORD.
001620*
001630     SET REGISTRY-DATA-IS-TEXT TO TRUE.
001640     MOVE 'Use AUTH' TO REGISTRY-VALUENAME.
001650     MOVE LOW-VALUES TO REGISTRY-DATA.
001660     SET FUNC-REGISTRY-GET TO TRUE.
001670     PERFORM 0101-API-CALL.
001680     IF NOT WIN32API-FAILED
001690       IF REGISTRY-DATA-LENGTH > ZERO
001700         MOVE REGISTRY-DATA (1:REGISTRY-DATA-LENGTH)
001710             TO SM-USE-AUTH.
001720*
001730*                         : break up our address for checking
001740     UNSTRING SM-YOUR-EMAIL DELIMITED '@' INTO
001750         WS-USER-EMAIL-NAME
001760         DELIMITER IN WS-USER-EMAIL-AT-SIGN
001770         WS-USER-EMAIL-DOMAIN.
001780*
001790 0103-SEND-MAIL.
001800*                         :---------------------------------------
001810* ------------------------: SENDING A MESSAGE
001820*                         : Here we build a smtp mail message and
001830*                         : send it.
001840*                         : You should be familiar with the
001850*                         : smtp protocol to follow this code. See
001860*                         : http://rfc.sunsite.dk/rfc/rfc2821.html
001870*                         :---------------------------------------
001880*
001890     MOVE SM-YOUR-NAME TO APM-YOUR-NAME
001900     MOVE SM-YOUR-EMAIL TO APM-YOUR-EMAIL
001910     MOVE SM-SMTP-SERVER TO APM-SMTP-SERVER
001920     MOVE SM-PORT TO APM-PORT
001930     MOVE LN-TO-NAME TO APM-TO-NAME
001940     MOVE LN-TO-EMAIL TO APM-TO-EMAIL
001950     MOVE LN-SUBJECT TO APM-SUBJECT
001960     MOVE LN-TEXT TO APM-TEXT
001970     MOVE SPACE TO APM-AUTHENTICATION
001980     IF SM-USE-AUTH-ON
001990       SET APM-AUTHENTICATE-DESIRED TO TRUE
002000       MOVE SM-YOUR-LOGIN-NAME TO
002010           APM-AUTHENTICATION-USERID
002020       MOVE SM-YOUR-PASSWORD TO
002030           APM-AUTHENTICATION-PASSWORD
002040     END-IF
002050*
002060     SET FUNC-SENDMAIL TO TRUE.
002070     CALL 'GSWINAPI' USING WIN32API-PARMS
002080                           APM-MAIL-PARMS
002090                           WIN32API-B
002100                           WIN32API-C
002110                           WIN32API-D
002120                           WIN32API-E
002130                           WIN32API-F.
002140     IF WIN32API-FAILED
002150       MOVE WIN32API-ERROR-TEXT TO LN-ERROR-TEXT
002160       SET LN-MESSAGE-FAILED TO TRUE
002170     ELSE
002180       MOVE 'Message Sent.....' TO LN-ERROR-TEXT
002190       SET LN-MESSAGE-SENT-OK TO TRUE.
